@@ -104,7 +104,7 @@ namespace LHAPDF {
       // hardcoded lookup table for particle ids
       // -6,...,-1,21/0,1,...,6,22
       // if id outside of this range, search in list of ids
-      if (id < 21) return _lookup[id + 6];
+      if (-6 <= id && id <= 6) return _lookup[id + 6];
       else if (id == 21) return _lookup[0 + 6];
       else if (id == 22) return _lookup[13];
       else return findPidInPids(id, _pids);
